# dora-openarm-dummy

A [dora-rs](https://dora-rs.ai/) node that mimics OpenArm for testing.

## License

Licensed under the Apache License 2.0. See [LICENSE](LICENSE) for details.

Copyright 2026 Enactic, Inc.

## Code of Conduct

All participation in the OpenArm project is governed by our [Code of Conduct](CODE_OF_CONDUCT.md).
